@@ -128,6 +128,9 @@ class Email(Common):
         if self.WebhookCallbackURL and not self.WebhookCallbackFormat :
             return MessageResult(error="Missing WebhookCallbackFormat - JSON or XML")
 
+        if not self.EmailSubject :
+            return MessageResult(error="Missing EmailSubject")
+
         if not self.MessagePlain and not self.MessageHTML:
             return MessageResult(error="Missing MessagePlain and MessageHTML")
 
